@@ -146,7 +146,9 @@ def extract_zip(data: BytesIO, path: Path) -> None:
             zip_path.unlink()
     else:
         with ZipFile(data, 'w') as zf:
+            logger.info('Extraindo!')
             zf.extractall(str(path))
+            logger.info('Extraido!')
     exec_path = chromium_executable()
     if not exec_path.exists():
         raise IOError('Failed to extract chromium.')
